@@ -1,5 +1,7 @@
 package Dancer2::Plugin::FormValidator::Extension::DBIC::Unique;
 
+use strict; use warnings;
+
 use Moo;
 use utf8;
 use namespace::clean;
@@ -18,13 +20,11 @@ sub validate {
     my ($self, $field, $input, $source, $attribute) = @_;
 
     if ($self->_field_defined_and_non_empty($field, $input)) {
-        my $result = $self->extension->schema->resultset($source)->search(
+        return not $self->extension->schema->resultset($source)->single(
             {
                 $attribute => $input->{$field},
             }
-        )->first;
-
-        return $result ? 0 : 1;
+        );
     }
 
     return 1;
